package Task::App::Physics::ParticleMotion;

use strict;

our $VERSION = '1.02';

=head1 NAME

Task::App::Physics::ParticleMotion - All modules required for the tk-motion application

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Task::App::Physics::ParticleMotion'>

=head1 DESCRIPTION

L<Config::Tiny>

L<Math::Project3D>

L<Math::RungeKutta>

L<Math::Symbolic>

L<Tk>

L<Tk::Cloth>

L<App::Physics::ParticleMotion>

=head1 AUTHOR

Steffen Mueller, C<module at steffen-mueller dot net>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

1;
